@@ -326,7 +326,7 @@ go_component_shapshot_finalize (GObject *obj)
 	GOComponentSnapshot *snapshot = (GOComponentSnapshot *) obj;
 
 	if (G_IS_OBJECT (snapshot->image))
-		g_object_unref (G_OBJECT (snapshot->image));
+		g_object_unref (snapshot->image);
 
 	(*snapshot_parent_klass->finalize) (obj);
 }
@@ -785,7 +785,9 @@ go_component_build_snapshot (GOComponent *component)
 	default:
 		return GO_SNAPSHOT_NONE;
 	}
-	if (cairo_surface_status (surface) != CAIRO_STATUS_SUCCESS)
+	if (cairo_surface_status (surface) == CAIRO_STATUS_SUCCESS)
+		res = component->snapshot_type;
+	else
 		res = GO_SNAPSHOT_NONE;
 
 	cairo_surface_destroy (surface);
