@@ -70,7 +70,7 @@ struct _GOComponentClass {
 	void (*set_size) (GOComponent *component);
 	void (*render) (GOComponent *component, cairo_t *cr,
 			    double width, double height);
-	void (*set_font) (GOComponent *component, PangoFontDescription *desc);
+	gboolean (*set_font) (GOComponent *component, PangoFontDescription const *desc);
 	/*<private>*/
 	void (*reserved1) (void);
 	void (*reserved2) (void);
@@ -116,7 +116,7 @@ GOCmdContext *go_component_get_command_context (GOComponent *component);
 void go_component_set_default_command_context (GOCmdContext *cc);
 void go_component_render (GOComponent *component, cairo_t *cr, double width, double height);
 void go_component_get_size (GOComponent *component, double *width, double *height);
-void go_component_set_font (GOComponent *component, PangoFontDescription *desc);
+gboolean go_component_set_font (GOComponent *component, PangoFontDescription const *desc);
 
 void go_component_write_xml_sax (GOComponent *component, GsfXMLOut *output);
 typedef void (*GOComponentSaxHandler)(GOComponent *component, gpointer user_data);
