@@ -1021,7 +1021,7 @@ axis_line_get_bbox (GogAxisBase *axis_base, GogRenderer *renderer,
 	tick_len = axis_base->major.tick_out ? major_tick_len :
 		(axis_base->minor.tick_out ? minor_tick_len : 0.);
 	gog_renderer_get_text_OBR (renderer, "0", TRUE, &txt_obr, -1.);
-	label_padding = txt_obr.w;
+	label_padding = txt_obr.h * .15;
 
 	total_bbox.x = x; total_bbox.y = y;
 	total_bbox.w = w; total_bbox.h = h;
@@ -1079,8 +1079,7 @@ axis_line_get_bbox (GogAxisBase *axis_base, GogRenderer *renderer,
 		if (ticks[i].str != NULL) {
 			GOGeometryOBR *obr = obrs + i;
 			pos = gog_axis_map_to_view (map, ticks[i].position);
-			obr->w += label_padding;
-			go_geometry_calc_label_position (obr, axis_angle, tick_len,
+			go_geometry_calc_label_position (obr, axis_angle, tick_len + label_padding,
 							 side, label_anchor);
 			obr->x += x + pos * cos (axis_angle);
 			obr->y += y + pos * sin (axis_angle);
@@ -1122,6 +1121,7 @@ axis_line_render (GogAxisBase *axis_base,
 	double pos, pos_x, pos_y;
 	double padding = gog_axis_base_get_padding (axis_base);
 	double label_size_max = 0;
+	double s, e;
 	unsigned i, tick_nbr, nobr = 0, *indexmap = NULL;
 	gboolean draw_major, draw_minor;
 	gboolean is_line_visible;
@@ -1133,22 +1133,21 @@ axis_line_render (GogAxisBase *axis_base,
 	x -= gog_renderer_pt2r_x (renderer, padding * cos_alpha);
 	y -= gog_renderer_pt2r_y (renderer, padding * sin_alpha);
 
-	axis_base_view->x_start = x;
-	axis_base_view->y_start = y;
-	axis_base_view->x_stop = x + w;
-	axis_base_view->y_stop = y + h;
+	gog_axis_get_effective_span (axis_base->axis, &s, &e);
+	axis_base_view->x_start = x + w * s;
+	axis_base_view->y_start = y + h * s;
+	axis_base_view->x_stop = x + w * e;
+	axis_base_view->y_stop = y + h * e;
 
 	is_line_visible = go_style_is_line_visible (style);
 	line_width = gog_renderer_line_size (renderer, style->line.width) / 2;
 
 	if (is_line_visible) {
 		/* draw the line only in the effective range */
-		double s, e;
-		gog_axis_get_effective_span (axis_base->axis, &s, &e);
 		path = go_path_new ();
 		go_path_set_options (path, sharp ? GO_PATH_OPTIONS_SHARP : 0);
-		go_path_move_to (path, x + w * s , y + h * s);
-		go_path_line_to (path, x + w * e, y + h * e);
+		go_path_move_to (path, axis_base_view->x_start , axis_base_view->y_start);
+		go_path_line_to (path, axis_base_view->x_stop, axis_base_view->y_stop);
 	}
 
 	map = gog_axis_map_new (axis_base->axis, 0., axis_length);
@@ -1171,7 +1170,7 @@ axis_line_render (GogAxisBase *axis_base,
 	tick_len = axis_base->major.tick_out ? major_tick_len :
 		(axis_base->minor.tick_out ? minor_tick_len : 0.);
 	gog_renderer_get_text_OBR (renderer, "0", TRUE, &zero_obr, -1.);
-	label_padding = zero_obr.w;
+	label_padding = zero_obr.h * .15;
 
 	tick_nbr = gog_axis_get_ticks (axis_base->axis, &ticks);
 	if (draw_labels) {
@@ -1230,8 +1229,7 @@ axis_line_render (GogAxisBase *axis_base,
 
 		if (ticks[i].str != NULL && draw_labels) {
 			GOGeometryOBR *obr = obrs + i;
-			obr->w += label_padding;
-			go_geometry_calc_label_position (obr, axis_angle, tick_len,
+			go_geometry_calc_label_position (obr, axis_angle, tick_len + label_padding,
 							 side, label_anchor);
 			if (ticks_pos) {
 				obr->x += ticks_pos[2 * i];
@@ -1337,7 +1335,7 @@ axis_circle_get_bbox (GogAxisBase *axis_base, GogRenderer *renderer,
 	tick_len = axis_base->major.tick_out ? major_tick_len :
 		(axis_base->minor.tick_out ? minor_tick_len : 0.);
 	gog_renderer_get_text_OBR (renderer, "0", TRUE, &txt_obr, -1.);
-	label_padding = txt_obr.w;
+	label_padding = txt_obr.h * .15;
 
 	draw_ticks = go_style_is_line_visible (axis_base->base.style) &&
 		(axis_base->major.tick_out || axis_base->minor.tick_out);
@@ -1352,8 +1350,7 @@ axis_circle_get_bbox (GogAxisBase *axis_base, GogRenderer *renderer,
 
 		if (ticks[i].str != NULL && draw_labels) {
 			gog_renderer_get_gostring_OBR (renderer, ticks[i].str, &txt_obr, -1.);
-			txt_obr.w += label_padding;
-			go_geometry_calc_label_position (&txt_obr, angle + M_PI / 2.0, tick_len,
+			go_geometry_calc_label_position (&txt_obr, angle + M_PI / 2.0, tick_len + label_padding,
 							 GO_SIDE_LEFT, GO_SIDE_AUTO);
 			txt_obr.x += x;
 			txt_obr.y += y;
@@ -1420,7 +1417,7 @@ axis_circle_render (GogAxisBase *axis_base, GogRenderer *renderer,
 	tick_len = axis_base->major.tick_out ? major_tick_len :
 		(axis_base->minor.tick_out ? minor_tick_len : 0.);
 	gog_renderer_get_text_OBR (renderer, "0", TRUE, &txt_obr, -1.);
-	label_padding = txt_obr.w;
+	label_padding = txt_obr.h * .15;
 
 	tick_nbr = gog_axis_get_ticks (axis_base->axis, &ticks);
 	for (i = 0; i < tick_nbr; i++) {
@@ -1476,8 +1473,7 @@ axis_circle_render (GogAxisBase *axis_base, GogRenderer *renderer,
 			gog_chart_map_2D_to_view (c_map, ticks[i].position, position,
 						  &label_pos.x, &label_pos.y);
 			gog_renderer_get_gostring_OBR (renderer, ticks[i].str, &txt_obr, -1.);
-			txt_obr.w += label_padding;
-			go_geometry_calc_label_position (&txt_obr, angle + M_PI / 2.0, tick_len,
+			go_geometry_calc_label_position (&txt_obr, angle + M_PI / 2.0, tick_len + label_padding,
 							 GO_SIDE_LEFT, GO_SIDE_AUTO);
 			label_pos.x += txt_obr.x;
 			label_pos.y += txt_obr.y;
