@@ -269,7 +269,7 @@ cb_history_changed (GOColorPalette *pal)
 	GOColorGroup *group = pal->group;
 
 	for (i = 0 ; i < GO_COLOR_GROUP_HISTORY_SIZE ; i++)
-		gtk_widget_override_background_color (pal->swatches [i], GTK_STATE_NORMAL,
+		gtk_widget_override_background_color (pal->swatches [i], GTK_STATE_FLAG_NORMAL,
 			go_color_to_gdk_rgba (group->history[i], &gdk));
 #if 0
 	if (next_swatch != NULL) {
@@ -300,7 +300,7 @@ swatch_activated (GOColorPalette *pal, GtkBin *button)
 	g_return_if_fail (swatch != NULL);
 
 	style_ctx = gtk_widget_get_style_context (swatch);
-	gtk_style_context_get_background_color (style_ctx, GTK_STATE_NORMAL, &rgba);
+	gtk_style_context_get_background_color (style_ctx, GTK_STATE_FLAG_NORMAL, &rgba);
 	set_color (pal, GO_COLOR_FROM_GDK_RGBA (rgba),
 		   FALSE, TRUE, FALSE);
 }
@@ -343,17 +343,17 @@ draw_color_cb (GtkWidget *widget, cairo_t *cr, gpointer data)
  * Utility function
  */
 static GtkWidget *
-go_color_palette_button_new (GOColorPalette *pal, GtkTable* table,
+go_color_palette_button_new (GOColorPalette *pal, GtkGrid *grid,
 			     GONamedColor const *color_name,
 			     gint col, gint row)
 {
-        GtkWidget *button, *swatch, *box;
+	GtkWidget *button, *swatch, *box;
 	GdkRGBA   gdk;
 
 	swatch = gtk_drawing_area_new ();
 	g_signal_connect (G_OBJECT (swatch), "draw", G_CALLBACK (draw_color_cb),
 	                  GUINT_TO_POINTER (color_name->color));
-	gtk_widget_override_background_color (swatch, GTK_STATE_NORMAL,
+	gtk_widget_override_background_color (swatch, GTK_STATE_FLAG_NORMAL,
 	        go_color_to_gdk_rgba (color_name->color, &gdk));
 	gtk_widget_set_size_request (swatch, COLOR_PREVIEW_WIDTH, COLOR_PREVIEW_HEIGHT);
 
@@ -367,8 +367,7 @@ go_color_palette_button_new (GOColorPalette *pal, GtkTable* table,
 	gtk_container_add (GTK_CONTAINER (button), box);
 	gtk_widget_set_tooltip_text (button, _(color_name->name));
 
-	gtk_table_attach (table, button, col, col+1, row, row+1,
-		GTK_FILL, GTK_FILL, 0, 0);
+	gtk_grid_attach (grid, button, col, row, 1, 1);
 
 	g_object_connect (button,
 		"signal::button_release_event", G_CALLBACK (cb_swatch_release_event), pal,
@@ -419,7 +418,7 @@ go_color_palette_set_group (GOColorPalette *p, GOColorGroup *cg)
 		g_signal_handlers_disconnect_by_func (
 			G_OBJECT (p->group),
 			G_CALLBACK (cb_history_changed), p);
-		g_object_unref (G_OBJECT (p->group));
+		g_object_unref (p->group);
 		p->group = NULL;
 	}
 	if (cg != NULL) {
@@ -437,15 +436,15 @@ go_color_palette_setup (GOColorPalette *pal,
 		     int cols, int rows,
 		     GONamedColor const *color_names)
 {
-	GtkWidget	*w, *table;
+	GtkWidget	*w, *grid;
 	int pos, row, col = 0;
 
-	table = gtk_table_new (cols, rows, FALSE);
+	grid = gtk_grid_new ();
 
 	if (no_color_label != NULL) {
 		w = gtk_button_new_with_label (no_color_label);
-		gtk_table_attach (GTK_TABLE (table), w,
-				  0, cols, 0, 1, GTK_FILL | GTK_EXPAND, 0, 0, 0);
+		gtk_widget_set_hexpand (w, TRUE);
+		gtk_grid_attach (GTK_GRID (grid), w, 0, 0, cols, 1);
 		g_signal_connect (w,
 			"button_release_event",
 			G_CALLBACK (cb_default_release_event), pal);
@@ -457,7 +456,7 @@ go_color_palette_setup (GOColorPalette *pal,
 			if (color_names [pos].name == NULL)
 				goto custom_colors;
 			go_color_palette_button_new ( pal,
-				GTK_TABLE (table),
+				GTK_GRID (grid),
 				&(color_names [pos]), col, row + 1);
 		}
 
@@ -468,20 +467,20 @@ custom_colors :
 		GONamedColor color_name = { 0, N_("custom") };
 		color_name.color = pal->group->history [col];
 		pal->swatches [col] = go_color_palette_button_new (pal,
-			GTK_TABLE (table),
+			GTK_GRID (grid),
 			&color_name, col, row + 1);
 	}
 
 	w = go_gtk_button_build_with_stock (_("Custom color..."),
 		GTK_STOCK_SELECT_COLOR);
 	gtk_button_set_alignment (GTK_BUTTON (w), 0., .5);
-	gtk_table_attach (GTK_TABLE (table), w, 0, cols,
-		row + 2, row + 3, GTK_FILL | GTK_EXPAND, 0, 0, 0);
+	gtk_widget_set_hexpand (w, TRUE);
+	gtk_grid_attach (GTK_GRID (grid), w, 0, row + 2, cols, 1);
 	g_signal_connect (G_OBJECT (w),
 		"clicked",
 		G_CALLBACK (cb_combo_custom_clicked), pal);
 
-	return table;
+	return grid;
 }
 
 void
@@ -707,6 +706,7 @@ go_color_palette_make_menu (char const *no_color_label,
 				goto custom_colors;
 			w = make_colored_menu_item (" ",
 				color_names [pos].color);
+			gtk_widget_set_tooltip_text (w, _(color_names[pos].name));
 			gtk_menu_attach (GTK_MENU (submenu), w,
 				col, col+1, table_row, table_row+1);
 			g_signal_connect (G_OBJECT (w),
