@@ -180,7 +180,6 @@ go_gtk_builder_load (char const *uifile,
 	GtkBuilder *gui;
 	GError *error = NULL;
 	gboolean ok = FALSE;
-	gboolean need_grid_update = (gtk_check_version (3, 2, 0) != NULL); /* remove when we require 3.2.0 or later */
 
 	g_return_val_if_fail (uifile != NULL, NULL);
 
@@ -222,19 +221,6 @@ go_gtk_builder_load (char const *uifile,
 	} else if (error)
 		g_error_free (error);
 
-	if (need_grid_update && gui) { /* remove when we require gtk+-3.2.0 or later */
-		GSList *l = gtk_builder_get_objects (gui), *ptr;
-		int rsep, csep;
-		ptr = l;
-		while (ptr) {
-			if (GTK_IS_GRID (ptr->data)) {
-				g_object_get (ptr->data, "row-spacing", &csep, "column-spacing", &rsep, NULL);
-				g_object_set (ptr->data, "row-spacing", rsep, "column-spacing", csep, NULL);
-			}
-			ptr = ptr->next;
-		}
-		g_slist_free (l);
-	}
 	return gui;
 }
 
@@ -941,7 +927,7 @@ go_gui_get_image_save_info (GtkWindow *toplevel, GSList *supported_formats,
 	GtkFileChooser *fsel = gui_image_chooser_new (TRUE);
 	GtkWidget *expander = NULL;
 	GtkWidget *resolution_spin = NULL;
-	GtkWidget *resolution_table;
+	GtkWidget *resolution_grid;
 	GtkBuilder *gui;
 	SaveInfoState *state;
 	char const *key = "go_gui_get_image_save_info";
@@ -1002,14 +988,14 @@ go_gui_get_image_save_info (GtkWindow *toplevel, GSList *supported_formats,
 			gtk_widget_hide (expander);
 
 		if (resolution != NULL && supported_formats != NULL && ret_format != NULL) {
-			resolution_table = go_gtk_builder_get_widget (gui, "resolution_table");
+			resolution_grid = go_gtk_builder_get_widget (gui, "resolution-grid");
 
-			cb_format_combo_changed (format_combo, resolution_table);
+			cb_format_combo_changed (format_combo, resolution_grid);
 			g_signal_connect (GTK_WIDGET (format_combo), "changed",
-					  G_CALLBACK (cb_format_combo_changed), resolution_table);
+					  G_CALLBACK (cb_format_combo_changed), resolution_grid);
 		}
 
-		g_object_unref (G_OBJECT (gui));
+		g_object_unref (gui);
 	}
 
 	if (state->uri != NULL) {
@@ -1165,10 +1151,10 @@ go_help_display (CBHelpPaths const *paths, GdkScreen *screen)
 				g_hash_table_insert (context_help_map, g_strdup (topic),
 					(gpointer)id);
 			}
-			g_object_unref (G_OBJECT (textline));
+			g_object_unref (textline);
 		}
 		if (input)
-			g_object_unref (G_OBJECT (input));
+			g_object_unref (input);
 		g_free (path);
 	}
 
