@@ -85,6 +85,7 @@ go_gradient_dir_from_str (char const *name)
 char const *
 go_gradient_dir_as_str (GOGradientDirection dir)
 {
-	return (dir < 0 || dir >= GO_GRADIENT_MAX) ? "gradient"
+	return (unsigned)dir >= GO_GRADIENT_MAX
+		? "gradient"
 		: grad_dir_names[dir];
 }
