@@ -350,8 +350,8 @@ gog_plot1_5d_class_init (GogPlotClass *plot_klass)
 			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, GOG_1_5D_PROP_IN_3D,
 		g_param_spec_boolean ("in-3d",
-			_("In 3d"),
-			_("Placeholder to allow us to round trip pseudo 3d state"),
+			_("In 3D"),
+			_("Placeholder to allow us to round trip pseudo 3D state"),
 			FALSE,
 			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 
