@@ -461,7 +461,7 @@ gog_bubble_plot_populate_editor (GogObject *obj,
 {
 	GtkWidget *w = gog_bubble_plot_pref (GOG_BUBBLE_PLOT (obj), cc);
 	go_editor_add_page (editor, w, _("Properties"));
-	g_object_unref (G_OBJECT (w));
+	g_object_unref (w);
 
 	(GOG_OBJECT_CLASS(bubble_parent_klass)->populate_editor) (obj, editor, dalloc, cc);
 }
@@ -1584,19 +1584,19 @@ gog_xy_view_render (GogView *view, GogViewAllocation const *bbox)
 					anchor = GO_ANCHOR_CENTER;
 					break;
 				case GOG_SERIES_LABELS_TOP:
-					alloc.y -= cur_offset;
+					alloc.y -= cur_offset * gog_renderer_get_scale (view->renderer);;
 					anchor = GO_ANCHOR_SOUTH;
 					break;
 				case GOG_SERIES_LABELS_BOTTOM:
-					alloc.y += cur_offset;
+					alloc.y += cur_offset * gog_renderer_get_scale (view->renderer);
 					anchor = GO_ANCHOR_NORTH;
 					break;
 				case GOG_SERIES_LABELS_LEFT:
-					alloc.x -= cur_offset;
+					alloc.x -= cur_offset * gog_renderer_get_scale (view->renderer);;
 					anchor = GO_ANCHOR_EAST;
 					break;
 				case GOG_SERIES_LABELS_RIGHT:
-					alloc.x += cur_offset;
+					alloc.x += cur_offset * gog_renderer_get_scale (view->renderer);;
 					anchor = GO_ANCHOR_WEST;
 					break;
 				}
@@ -2093,7 +2093,7 @@ gog_xy_series_populate_editor (GogObject *obj,
 			"toggled",
 			G_CALLBACK (invalid_toggled_cb), obj);
 
-		w = go_gtk_builder_get_widget (gui, "gog_xy_series_prefs");
+		w = go_gtk_builder_get_widget (gui, "gog-xy-series-prefs");
 
 		go_editor_add_page (editor, w, _("Details"));
 		g_object_unref (gui);
